==> adams-weka-0.3.25-sources.jar: adams/gui/menu/GraphVisualizer.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * GraphVisualizer.java
 * Copyright (C) 2009 University of Waikato, Hamilton, New Zealand
 *
 */

package adams.gui.menu;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileReader;

import javax.swing.JFileChooser;
import javax.swing.JOptionPane;

import adams.core.io.PlaceholderFile;
import adams.gui.application.AbstractApplicationFrame;
import adams.gui.application.ChildFrame;
import adams.gui.application.UserMode;
import adams.gui.core.ExtensionFileFilter;

/**
 * Displays data in the graph visualizer.
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 4584 $
 * @see weka.gui.graphvisualizer.GraphVisualizer
 */
public class GraphVisualizer
  extends AbstractParameterHandlingWekaMenuItemDefinition {

  /** for serialization. */
  private static final long serialVersionUID = -771667287275117680L;

  /** filechooser for GraphVisualizers. */
  protected JFileChooser m_FileChooser;

  /**
   * Initializes the menu item with no owner.
   */
  public GraphVisualizer() {
    this(null);
  }

  /**
   * Initializes the menu item.
   *
   * @param owner	the owning application
   */
  public GraphVisualizer(AbstractApplicationFrame owner) {
    super(owner);
  }

  /**
   * Initializes members.
   */
  protected void initialize() {
    super.initialize();

    m_FileChooser = new JFileChooser(new File(System.getProperty("user.dir")));
    m_FileChooser.addChoosableFileFilter(new ExtensionFileFilter("XML BIF file", "xml"));
  }

  /**
   * Launches the functionality of the menu item.
   */
  public void launch() {
    String filename;
    if (m_Parameters.length == 0) {
      // choose file
      int retVal = m_FileChooser.showOpenDialog(getOwner());
      if (retVal != JFileChooser.APPROVE_OPTION)
	return;
      filename = m_FileChooser.getSelectedFile().getAbsolutePath();
    }
    else {
      filename = new PlaceholderFile(m_Parameters[0]).getAbsolutePath();
    }

    // build graph
    weka.gui.graphvisualizer.GraphVisualizer panel = new weka.gui.graphvisualizer.GraphVisualizer();
    try{
      if (    filename.toLowerCase().endsWith(".xml")
	  || filename.toLowerCase().endsWith(".bif") ) {
	panel.readBIF(new FileInputStream(filename));
      }
      else {
	panel.readDOT(new FileReader(filename));
      }
    }
    catch (Exception e) {
      e.printStackTrace();
      JOptionPane.showMessageDialog(
	  getOwner(), "Error loading file '" + filename + "':\n" + e.getMessage());
      return;
    }

    // create frame
    ChildFrame frame = createChildFrame(panel, 800, 600);
    frame.setTitle(frame.getTitle()  + " - " + filename);
  }

  /**
   * Returns the title of the window (and text of menuitem).
   *
   * @return 		the title
   */
  public String getTitle() {
    return "GraphVisualizer";
  }

  /**
   * Whether the panel can only be displayed once.
   *
   * @return		true if the panel can only be displayed once
   */
  public boolean isSingleton() {
    return false;
  }

  /**
   * Returns the user mode, which determines visibility as well.
   *
   * @return		the user mode
   */
  public UserMode getUserMode() {
    return UserMode.BASIC;
  }
}

==> adams-weka-0.4.1-sources.jar: adams/gui/menu/GraphVisualizer.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * GraphVisualizer.java
 * Copyright (C) 2009 University of Waikato, Hamilton, New Zealand
 *
 */

package adams.gui.menu;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileReader;

import javax.swing.JOptionPane;

import adams.core.io.PlaceholderFile;
import adams.gui.application.AbstractApplicationFrame;
import adams.gui.application.ChildFrame;
import adams.gui.application.UserMode;
import adams.gui.chooser.BaseFileChooser;
import adams.gui.core.ExtensionFileFilter;

import com.googlecode.vfsjfilechooser2.VFSJFileChooser.RETURN_TYPE;

/**
 * Displays data in the graph visualizer.
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 5651 $
 * @see weka.gui.graphvisualizer.GraphVisualizer
 */
public class GraphVisualizer
  extends AbstractParameterHandlingWekaMenuItemDefinition {

  /** for serialization. */
  private static final long serialVersionUID = -771667287275117680L;

  /** filechooser for GraphVisualizers. */
  protected BaseFileChooser m_FileChooser;

  /**
   * Initializes the menu item with no owner.
   */
  public GraphVisualizer() {
    this(null);
  }

  /**
   * Initializes the menu item.
   *
   * @param owner	the owning application
   */
  public GraphVisualizer(AbstractApplicationFrame owner) {
    super(owner);
  }

  /**
   * Initializes members.
   */
  protected void initialize() {
    super.initialize();

    m_FileChooser = new BaseFileChooser(new File(System.getProperty("user.dir")));
    m_FileChooser.addChoosableFileFilter(new ExtensionFileFilter("XML BIF file", "xml"));
  }

  /**
   * Launches the functionality of the menu item.
   */
  public void launch() {
    String filename;
    if (m_Parameters.length == 0) {
      // choose file
      RETURN_TYPE retVal = m_FileChooser.showOpenDialog(getOwner());
      if (retVal != RETURN_TYPE.APPROVE)
	return;
      filename = m_FileChooser.getSelectedFile().getAbsolutePath();
    }
    else {
      filename = new PlaceholderFile(m_Parameters[0]).getAbsolutePath();
    }

    // build graph
    weka.gui.graphvisualizer.GraphVisualizer panel = new weka.gui.graphvisualizer.GraphVisualizer();
    try{
      if (    filename.toLowerCase().endsWith(".xml")
	  || filename.toLowerCase().endsWith(".bif") ) {
	panel.readBIF(new FileInputStream(filename));
      }
      else {
	panel.readDOT(new FileReader(filename));
      }
    }
    catch (Exception e) {
      e.printStackTrace();
      JOptionPane.showMessageDialog(
	  getOwner(), "Error loading file '" + filename + "':\n" + e.getMessage());
      return;
    }

    // create frame
    ChildFrame frame = createChildFrame(panel, 800, 600);
    frame.setTitle(frame.getTitle()  + " - " + filename);
  }

  /**
   * Returns the title of the window (and text of menuitem).
   *
   * @return 		the title
   */
  public String getTitle() {
    return "GraphVisualizer";
  }

  /**
   * Whether the panel can only be displayed once.
   *
   * @return		true if the panel can only be displayed once
   */
  public boolean isSingleton() {
    return false;
  }

  /**
   * Returns the user mode, which determines visibility as well.
   *
   * @return		the user mode
   */
  public UserMode getUserMode() {
    return UserMode.BASIC;
  }
}
